@@ -25,10 +25,7 @@
 #include <string.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
-#include <glib/gerror.h>
-#include <glib/glist.h>
-#include <glib/gstrfuncs.h>
-#include <glib/gmessages.h>
+#include <glib.h>
 #include <gconf/gconf-client.h>
 #include <musicbrainz/queries.h>
 #include <musicbrainz/mb_c.h>
